#
# spec file for package Srain
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           Srain
Version:        1.5.0
Release:        bp156.2.8
Summary:        An IRC client
License:        GPL-3.0-or-later AND ISC
URL:            https://srain.im
Source:         https://github.com/SrainApp/srain/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.47.0
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  pkgconfig(appstream)
BuildRequires:  pkgconfig(glib-2.0) >= 2.39.3
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.15
BuildRequires:  pkgconfig(libconfig) >= 1.5
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(openssl)

%description
IRC client written in GTK3+.

%lang_package

%prep
%autosetup -p1 -n srain-%{version}

%build
%meson -Ddoc_builders=man
%meson_build

%install
%meson_install
%find_lang srain

%files
%license LICENSE
%doc README.rst
%dir %{_datadir}/srain
%dir %{_datadir}/srain/themes
%dir %{_sysconfdir}/srain
%config %{_sysconfdir}/srain/builtin.cfg
%{_bindir}/srain
%{_datadir}/applications/im.srain.%{name}.desktop
%{_datadir}/icons/hicolor/128x128/apps/im.srain.%{name}.png
%{_datadir}/icons/hicolor/128x128/apps/im.srain.%{name}.Red.png
%{_datadir}/metainfo/im.srain.%{name}.metainfo.xml
%{_datadir}/srain/themes/*.css
%{_mandir}/man1/srain.1%{?ext_man}

%files lang -f srain.lang

%changelog
* Wed Jan 11 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.5.0
  Features:
  * Able to identify Nordic GTK Theme as dark theme
  * Activate the corresponding buffer to a response user query
  Changes:
  * Suppress error message when connection keeps failing
  Bug fixes:
  * Fix SASL authentication error when connecting to Soju
- Update to version 1.4.0
  Features:
  * Add support for IRCv3 standard-replies
  * Add support for SASL EXTERNAL, invite-notify, server-time
  * Add conf item server-visibility for setting default server visiblity
  * Add /clear command for clearing messages of current buffer
* Fri Feb 11 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.2
  Features:
  * Add French translation
  Bug fixes:
  * Silence assertion failure on /part command
  * Silence "Unknown capability" warning on trailing whitespace
  Changes:
  * Add tooltips to buttons with no text
* Sat Dec 18 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.1
  * Make channel messages with origin out of channels can be shown
  * Rejoin channels after NICKSERV authentication finishes
* Tue Oct 26 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Update to version 1.3.0
  - [1.3.0]
  * Features:
    + Implement ISUPPORT parsing + the UTF8ONLY IRCv3 specification
    + Add support for RPL_UMODEIS
    + Make nick completion case-insensitive
    + Add button for inserting emoji
  * Bug fixes:
    + Fix configuration syntax errors caused by trailing commas
  - [1.2.4]
  * Bug fixes
    + Fix bugs introduced by https://github.com/SrainApp/srain/pull/316
    + Fix crach when URL preview async task failed
  - [1.2.3]
  * Bug fixes:
    + Eliminate GDK warning
  - [1.2.2]
  * Changed:
    + Add libera.chat IRC network (#311)
    + Updated Dutch translation (b6830e9)
* Sat Apr 10 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.1
  Features:
  * Add Ukrainian translations
  Bug fixes:
  * Minor fixes
* Sun Feb 28 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.0
  Features:
  * Switch build system from Make to Meson
  * Add ``/quote`` command for sending special IRC commands
  * Add support for hiding server buffer
  Bug fixes:
  * Fix an use-after-free BUG
  * Fix implicit declaration error on some systems
- Switch build to meson
- Drop Srain-no_implicit_declarations.patch (merged upstream)
* Sun Oct  4 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.3
  * fix an use-after-free case
  * remove server when main loop is idle
- Add Srain-no_implicit_declarations.patch
* Sat Jun 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.1
  Changes:
  * Improve auto-scroll policy of message list
  Bug fixes:
  * Fix TLS certificate verification error on glib-networking
    2.64.3
  * Fix crash when connecting to an invalid host
* Sun May 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.0
  Features:
  * Support multiple selection of message (#138)
  * Support jump to mentioned message (#243)
  * Nickname will be highlighted when mentioned (#243)
  Changes:
  * Improve fcous control of UI
  * Replace appdata with metainfo (#240)
  * Validate metainfo with appstream-util (#242)
  Bug fixes:
  * Some implicit declarations fixes (#236)
  * Some typo fixes (#239)
- Drop Srain-implicit_declarations.patch (merged upstream)
* Sat Apr 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.2
  Features:
  * Add MAN documentation (deaf723)
  * Add more predefined IRC networks: DALnet, EFnet, IRCnet,
    Undernet and QuakeNet (#228)
  Changes:
  * Build: Allow setting CC variable via environment (#224)
  * Add channel related messages to corresponding buffer as
    possible (#149)
  * Improve widget focus control (#229)
  * Drop unused icons (6239fe5)
  * Provide clearer error message when connecting (#233)
  Bug fixes:
  * Truncate long message before sendisg (#227)
  * Deal with invalid UTF-8 string (50e7757)
  * Fix incorrect user number of channel user list (#230)
  * Fix incorrect icon install path (9f07380)
- Refreshed Srain-implicit_declarations.patch
* Sat Mar 14 2020 aloisio@gmx.com
- Update to version 1.0.1
  Features:
  * Auto rename to original nick when ghost quit (#198)
  * Add hackint IRC network (#201), thanks to @kpcyrd
  * Add Dutch translation (#215), thanks to @Vistaus
  * Add two FAQs to documentation (#217)
  Changes:
  * Make header bar buttons repect default belief (#205, #218)
  Bug fixes:
  * Fix case sensitivity issue for IRC messages (#202), thanks
    to @hhirtz
  * Fix invalid changelog section of appdata file (#214)
  * Fix missing dependences in documentation (#216), thanks to
    @avoidr
* Mon Feb 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0
  * Some code cleanup
  * Update :doc:`./start` documentation
  * Allow Srain runs without dbus secrets service (:issue:`195`)
  * Fix nick generation logical (:commit:`39ced08`)
* Mon Oct  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0rc9999 (see
  http://doc.srain.im/en/latest/changelog.html#version-1-0-0rc9999)
* Fri Jun 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0rc5
  Added:
  * Regular expression pattern management using
    :ref:`commands-pattern` command
  * Add command :ref:`commands-filter` for filtering message via
    pattern
  * Add command :ref:`commands-render` for rendering message via
    pattern
  Changed:
  * Refactor detector module and rename it to render
  * Refactor filter module
  * Change project description
  Removed:
  * Drop command :ref:`commands-rignore`
  * Drop command :ref:`commands-relay`
* Mon May 13 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0rc4
  Added:
  * New dependency `libsecret`
  * Add password storage support
  * Add command line options "--no-auto", used to require Srain
    not to automatically connect to servers
  * Add russian translation, thanks to @tim77
  * Allow user send slash(``/``) prefixed message
  Removed:
  * Drop all password fields in configuration file
  Changed:
  * Enable CSD(Client-Side Decoration) by default
  * Update chinese translation
- Updated Srain-implicit_declarations.patch
* Sun Apr 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0rc3 (no changelog supplied)
* Thu Jan 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.0rc2 (no changelog supplied)
- Dropped Srain-flags.patch (merged upstream)
- Dropped Srain-iconsizes.patch (no longer necessary)
- Refreshed Srain-implicit_declarations.patch
* Sun Feb  4 2018 aloisio@gmx.com
- Initial package (0.06.3)
